from random import randint, sample


def generate_rgpd_password():
    letters = "aAbBcCdDeEfFgGhHiIjJkKlLmMnNoOpPqQrRsStTuUvVwWxXyYzZ"
    specials = "*/^~²#@àéèù%ç&-'_"
    passwd = ""
    for k in range(0, 10):
        passwd += letters[randint(0, len(letters) - 1)]
    for i in range(0, 5):
        passwd += specials[randint(0, len(specials) - 1)]
    for j in range(0, 3):
        passwd += str(randint(0, 9))
        
    return ''.join(sample(passwd,len(passwd)))


from setuptools import setup, find_packages

setup(
    name="rgpd_password",
    version="1.0",
    description="Tools to generate RGPD friendly password",
    author="Arthur RICHARD",
    packages=find_packages(),
    license="MIT",
    entry_points={
        "console_scripts": [
            "rgpd_gen=pwd_gen.randomize:generate_rgpd_password"
        ]
    }
)